@@ -57,7 +57,7 @@ def setup():
         else:
             flag = True
 
-        if not flag:
+        if flag:
             convert(source, source_format, destination, format)
         else:
             raise ValueError(f'Not correct config file: {formats.keys()}')
